summaryrefslogtreecommitdiff
path: root/src/de/danoeh/antennapod
diff options
context:
space:
mode:
authordaniel oeh <daniel.oeh@gmail.com>2012-09-27 15:24:57 +0200
committerdaniel oeh <daniel.oeh@gmail.com>2012-09-27 15:24:57 +0200
commiteb44579fa8d12c36bd6ca1dc63cb4d1a6b8e64c2 (patch)
treeb4fbff865083a99e75280d9cf5e8846837176ca5 /src/de/danoeh/antennapod
parent1e8f31b979ae35eb7c0321c0d9717b92ea6e3940 (diff)
downloadAntennaPod-eb44579fa8d12c36bd6ca1dc63cb4d1a6b8e64c2.zip
Use title as the first alternative of the feed identifier0.9.5
Diffstat (limited to 'src/de/danoeh/antennapod')
-rw-r--r--src/de/danoeh/antennapod/feed/Feed.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/de/danoeh/antennapod/feed/Feed.java b/src/de/danoeh/antennapod/feed/Feed.java
index 76f6a6fa5..45cd2b9b5 100644
--- a/src/de/danoeh/antennapod/feed/Feed.java
+++ b/src/de/danoeh/antennapod/feed/Feed.java
@@ -122,16 +122,16 @@ public class Feed extends FeedFile {
/**
* Returns the value that uniquely identifies this Feed. If the
* feedIdentifier attribute is not null, it will be returned. Else it will
* try to return the download URL. If the download URL is not given, it will use the title
* of the feed.
* */
public String getIdentifyingValue() {
if (feedIdentifier != null) {
return feedIdentifier;
- } else if (download_url != null) {
- return download_url;
- } else {
+ } else if (title != null) {
return title;
+ } else {
+ return link;
}
}
@@ -122,16 +122,16 @@ public class Feed extends FeedFile {
* Returns the value that uniquely identifies this Feed. If the
* feedIdentifier attribute is not null, it will be returned. Else it will
- * try to return the download URL. If the download URL is not given, it will use the title
+ * try to return the title. If the title is not given, it will use the link
* of the feed.
* */